@@ -24,7 +24,7 @@ def serve(ip: str, port: int, passwd: str, sync):
         以表示处理成功与否，若成功taskhub将移除改该Task]
     """
 
-    p = Process(ip=ip, target=start_hub_serve, args=(port, passwd, sync,))
+    p = Process(target=start_hub_serve, args=(ip, port, passwd, sync,))
     p.start()
     time.sleep(3)
     hub = connect(ip, port, passwd)
